# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   框架
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023/11/4 14:04
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------
import openpyxl

from InterfaceAutoTest_2.common import log
from InterfaceAutoTest_2.common.read_ini import ReadIni
from InterfaceAutoTest_2.common.read_json import read_json


class ReadExcel:
    def __init__(self):
        """获取数据配置层中，除了ini文件以外的所有文件的路径，再获取excel的工作表，再读取所有的json文件"""
        self.read_ini = ReadIni()
        excel_path = self.read_ini.get_file_path("excel")
        case_data_path = self.read_ini.get_file_path("case")
        except_data_path = self.read_ini.get_file_path("expect")
        sql_data_path = self.read_ini.get_file_path("sql")

        # 获取工作表名称
        table_name = self.read_ini.get_table_name("table_name")

        wb = openpyxl.load_workbook(excel_path)

        try:
            self.ws = wb[table_name]

        except:
            log.error("获取工作表失败，请查看工作表名称是否配置正确")
            raise KeyError("获取工作表失败，请查看工作表名称是否配置正确")

        self.case_data_dict = read_json(case_data_path)
        self.except_data_dict = read_json(except_data_path)
        self.sql_data_dict = read_json(sql_data_path)

    def __get_cell_value(self, column, row):
        try:
            value = self.ws[column + str(row)].value

            if value is None:
                return None
            elif value.strip():
                return value.strip()
        except:
            log.error("获取指定单元格数据失败，请查看输入的列号和行号是否正确")
            raise KeyError("获取指定单元格数据失败，请查看输入的列号和行号是否正确")

    def module_name(self, row):
        """根据行号获取模块名称"""
        return self.__get_cell_value("B", row)

    def api_name(self, row):
        """根据行号获取接口名称"""
        return self.__get_cell_value("c", row)

    def case_url(self, row):
        """根据行号获取请求的url"""
        return self.read_ini.get_host("host") + self.__get_cell_value("f", row)

    def case_method(self, row):
        """根据行号获取请求的方法"""
        return self.__get_cell_value("g", row)

    def case_mime(self, row):
        """根据行号，获取媒体类型"""
        mime = self.__get_cell_value("h", row)
        if mime:
            return mime.lower()

    def case_data(self, row):
        """根据行号，获取用例数据"""
        case_data_key = self.__get_cell_value("i", row)

        if case_data_key:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            try:
                return self.case_data_dict[module_name][api_name][case_data_key]
            except:
                log.error("请查看是否配置了用例数据")
                raise KeyError("请查看是否配置了用例数据")

    def except_data(self, row):
        """根据行号，获取期望数据"""
        except_data_key = self.__get_cell_value("j", row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        try:
            return self.except_data_dict[module_name][api_name][except_data_key]
        except:
            log.error("请查看是否配置了期望数据")
            raise KeyError("请查看是否配置了期望数据")

    def sql_type(self, row):
        """根据行号，获取sql语句类型"""
        sql_type_value = self.__get_cell_value("k", row)

        if sql_type_value:
            return sql_type_value.lower()

    def sql_data(self, row):
        """根据行号，获取sql语句"""
        sql_data_key = self.__get_cell_value("l", row)

        if sql_data_key:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            try:
                return self.sql_data_dict[module_name][api_name][sql_data_key]
            except:
                log.error("请查看是否配置了sql语句")
                raise KeyError("请查看是否配置了sql语句")
    def update_key(self, key):
        """根据行号，获取更新的key"""
        return self.__get_cell_value("m", key)

    def get_data(self):
        """将测试数据存放再一个二维列表中"""
        list_data = []
        for row in range(2, self.ws.max_row + 1):
            # url
            case_url = self.case_url(row)
            # method
            case_method = self.case_method(row)
            # mime
            case_mime = self.case_mime(row)
            # case_data
            case_data = self.case_data(row)
            # expect_data
            expect_data = self.except_data(row)
            # sql_type
            sql_type = self.sql_type(row)
            # sql_data
            sql_data = self.sql_data(row)
            # update_key
            update_key = self.update_key(row)
            list_data.append([case_url, case_method, case_mime, case_data, expect_data, sql_type, sql_data, update_key])

        else:
            return list_data


if __name__ == '__main__':
    excel = ReadExcel()
    print(excel.get_data())



